:github_url: https://github.com/stephane-caron/pink/tree/master/doc/src/installation.rst

************
Installation
************

First, install `Pinocchio <https://github.com/stack-of-tasks/pinocchio>`_, for instance by ``pip install pin``. Then install Pink by:

.. code:: bash

    pip install pin-pink
